Tax-Brain Python API
==============================

The source code for Tax-Brain is located in the
`Tax-Brain/taxbrain` directory tree.

Here we provide a high-level view of the Python API of the Tax-Brain model, with
links to the source code.  This high-level view is
organized around the modules that make up the Tax-Brain model.  Below is a list
of these modules (in alphabetical order) with
documentation about how to call each class method and function.
There is also a link to the source code for each documented member.


.. toctree::
   :maxdepth: 1

   cli
   corporate_incidence
   report
   report_utils
   taxbrain
   utils
